<?php

use Symfony\Component\Console\Output\ConsoleOutput;
use Drupal\simple_survey\Entity\SimpleSurvey;

/**
 * Implements hook_drush_command().
 */
function simple_survey_drush_command() {
  $commands = [];

  if (class_exists('Google\Cloud\BigQuery\BigQueryClient')) {
    $commands['send-responses-to-bigquery'] = [
      'description' => 'Send survey tool responses to Big Query',
      'drupal dependencies' => ['simple_survey'],
      'aliases' => ['ss:srbq']
    ];
  }

  return $commands;
}

/**
 * Call back function drush_custom_drush_command_send_responses_to_bigquery()
 * The call back function name in the  following format
 *   drush_{module_name}_{item_id_for_command}()
 */
function drush_simple_survey_send_responses_to_bigquery() {
  /**
   * @var \Drupal\simple_survey\Service\ResponseExportService $responseExport
   *   The response export service.
   */
  $responseExport = \Drupal::service('simple_survey.response_export');
  /**
   * @var \Drupal\simple_survey\Service\BigQueryConnect $bigQuery
   *   The bigQueryConnect Service.
   */
  $bigQuery = \Drupal::service('simple_survey.big_query');
  $surveys = SimpleSurvey::loadMultiple();

  $output = new ConsoleOutput();

  foreach ($surveys as $survey) {
    $bigQuery->setSurvey($survey);
    $responseExport->survey = $survey;

    if (!$bigQuery->checkConfigured()) {
      $output->writeln('<error>Big Query is not configured.</error>');
    }
    else {
      $output->writeln('<info>Converting Data for ' . $survey->label() . '</info>');

      $csv = $responseExport->convertDataToCsv();

      $output->writeln('<info>Submitting to BigQuery for ' . $survey->label() . '</info>');

      if ($bigQuery->updateTable($survey->bigQueryDataset, $survey->bigQueryTable, $csv)) {
        $output->writeln('<info>Submission Complete for ' . $survey->label() . '.</info>');
      }
      else {
        $output->writeln('<error>Submission Failed for ' . $survey->label() . '. Check the error log for more details.</error>');
      }
    }
  }
}
